# This file is MACHINE GENERATED! Do not edit.
# Generated by: tensorflow/python/tools/api/generator/create_python_api.py script.
"""Public API for tf.keras.__internal__.utils namespace.
"""

import sys as _sys

from keras.engine.data_adapter import get_data_handler
from keras.testing_infra.test_utils import layer_test
from keras.utils.tf_utils import register_symbolic_tensor_type